#
# spec file for package v4l-utils
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _udevdir %(pkg-config --variable udevdir udev)
%define so_ver 0

Name:           v4l-utils
Version:        1.0.1
Release:        0
Summary:        Utilities for video4linux and DVB devices
License:        GPL-2.0+ and GPL-2.0
Group:          Hardware/TV
Url:            http://linuxtv.org/downloads/v4l-utils/
Source0:        http://linuxtv.org/downloads/v4l-utils/%{name}-%{version}.tar.bz2
Source100:      baselibs.conf
# PATCH-FIX-UPSTREAM bufferoverflowstrncat.patch asterios.dramis@gmail.com -- Fix rpm post build check error "Statement might be overflowing a buffer in strncat"
Patch0:         bufferoverflowstrncat.patch
%if 0%{?suse_version} > 1210
BuildRequires:  desktop-file-utils
%else
BuildRequires:  update-desktop-files
%endif
BuildRequires:  kernel-headers
BuildRequires:  libjpeg-devel
BuildRequires:  libqt4-devel
BuildRequires:  pkg-config
BuildRequires:  udev
Requires:       libv4l = %{version}
Requires:       udev
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
v4l-utils is a collection of various video4linux (V4L) and DVB utilities.

%package devel-tools
Summary:        Utilities for v4l2 / DVB driver development and debugging
License:        GPL-2.0+ and GPL-2.0
Group:          Hardware/TV
Requires:       libv4l = %{version}

%description devel-tools
Utilities for v4l2 / DVB driver authors.

%package -n libv4l
Summary:        Collection of video4linux support libraries
License:        LGPL-2.1+ and GPL-2.0
Group:          System/Libraries

%description -n libv4l
libv4l is a collection of libraries which adds a thin abstraction layer on
top of video4linux2 devices. The purpose of this (thin) layer is to make it
easy for application writers to support a wide variety of devices without
having to write separate code for different devices in the same class.

%package -n libv4l1-%{so_ver}
Summary:        Video4linux support library
License:        LGPL-2.1+
Group:          System/Libraries
Requires:       libv4l

%description -n libv4l1-%{so_ver}
libv4l1 offers the (deprecated) v4l1 API on top of v4l2 devices, independent
of the drivers for those devices supporting v4l1 compatibility (which many
v4l2 drivers do not).

This package contains shared lib for packages that use libv4l1.

%package -n libv4l2-%{so_ver}
Summary:        Video4linux support library
License:        LGPL-2.1+
Group:          System/Libraries
Requires:       libv4l

%description -n libv4l2-%{so_ver}
libv4l2 offers the v4l2 API on top of v4l2 devices, while adding for the
application transparent libv4lconvert conversion where necessary.

This package contains shared lib for packages that use libv4l2.

%package -n libv4l2rds%{so_ver}
Summary:        Video4linux support library
License:        LGPL-2.1+
Group:          System/Libraries
Requires:       libv4l

%description -n libv4l2rds%{so_ver}
libv4l2rds offers decoding raw RDS data from V4L2 Radio devices and simple ways
to access the received RDS information.

This package contains shared lib for packages that use libv4l2rds.

%package -n libv4lconvert%{so_ver}
Summary:        Video4linux support library
License:        LGPL-2.1+
Group:          System/Libraries
Requires:       libv4l

%description -n libv4lconvert%{so_ver}
libv4lconvert offers functions to convert from any (known) pixel-format
to V4l2_PIX_FMT_BGR24 or V4l2_PIX_FMT_YUV420.

This package contains shared lib for packages that use libv4lconvert.

%package -n libv4l-devel
Summary:        Development files for libv4l
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       libv4l1-%{so_ver} = %{version}
Requires:       libv4l2-%{so_ver} = %{version}
Requires:       libv4l2rds%{so_ver} = %{version}
Requires:       libv4lconvert%{so_ver} = %{version}

%description -n libv4l-devel
The libv4l-devel package contains libraries and header files for
developing applications that use libv4l.

%package -n     qv4l2
Summary:        Video4linux test control and streaming test application
License:        GPL-2.0+
Group:          Hardware/TV
Requires:       libv4l = %{version}

%description -n qv4l2
qv4l2 is a test control and streaming test application for video4linux.

%prep
%setup -q
%patch0

%build
%configure --disable-static --disable-silent-rules --with-udevdir=%{_udevdir}
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install

# Remove libtool config files
find %{buildroot}%{_libdir} -name '*.la' -exec rm -f {} ';'

# Not needed (links to plugins in libv4l subdir)
rm %{buildroot}%{_libdir}/{v4l1compat.so,v4l2convert.so}

%if 0%{?suse_version} > 1210
desktop-file-edit --set-name="QV4l2" --set-generic-name="V4L2 Test Utility" \
 --add-category=Qt --add-category=Video --add-category=TV %{buildroot}%{_datadir}/applications/qv4l2.desktop
%else
%suse_update_desktop_file -N "QV4l2" -G "V4L2 Test Utility" -r qv4l2 Qt AudioVideo Video TV
%endif

%post -n libv4l1-%{so_ver} -p /sbin/ldconfig

%postun -n libv4l1-%{so_ver} -p /sbin/ldconfig

%post -n libv4l2-%{so_ver} -p /sbin/ldconfig

%postun -n libv4l2-%{so_ver} -p /sbin/ldconfig

%post -n libv4l2rds%{so_ver} -p /sbin/ldconfig

%postun -n libv4l2rds%{so_ver} -p /sbin/ldconfig

%post -n libv4lconvert%{so_ver} -p /sbin/ldconfig

%postun -n libv4lconvert%{so_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc COPYING ChangeLog README TODO
%dir %{_sysconfdir}/rc_keymaps/
%config(noreplace) %{_sysconfdir}/rc_maps.cfg
%{_udevdir}/rc_keymaps/
%if 0%{?suse_version} <= 1310
%dir %{_udevdir}/rules.d/
%endif
%{_udevdir}/rules.d/70-infrared.rules
%{_bindir}/cx18-ctl
%{_bindir}/dvb-*
%{_bindir}/dvbv5-*
%{_bindir}/ir-keytable
%{_bindir}/ivtv-ctl
%{_bindir}/rds-ctl
%{_bindir}/v4l2-ctl
%{_bindir}/v4l2-sysfs-path
%{_mandir}/man1/ir-keytable.1%{ext_man}

%files devel-tools
%defattr(-,root,root,-)
%doc COPYING ChangeLog README TODO
%{_bindir}/decode_tm6000
%{_bindir}/v4l2-compliance
%{_sbindir}/v4l2-dbg

%files -n libv4l
%defattr(-,root,root,-)
%doc COPYING.libv4l ChangeLog README README.libv4l TODO
%{_libdir}/libv4l/

%files -n libv4l1-%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libv4l1.so.%{so_ver}*

%files -n libv4l2-%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libv4l2.so.%{so_ver}*

%files -n libv4l2rds%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libv4l2rds.so.%{so_ver}*

%files -n libv4lconvert%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libv4lconvert.so.%{so_ver}*

%files -n libv4l-devel
%defattr(-,root,root,-)
%doc README.lib-multi-threading
%{_includedir}/libv4l*.h
%{_libdir}/libv4l*.so
%{_libdir}/pkgconfig/*.pc

%files -n qv4l2
%defattr(-,root,root,-)
%doc COPYING ChangeLog README TODO
%{_bindir}/qv4l2
%{_datadir}/applications/qv4l2.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/??x??
%dir %{_datadir}/icons/hicolor/??x??/apps
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/*/apps/qv4l2.*

%changelog
